# pycadc
The pycadc library is made to monitor the changes of a sql server database by activating the CDC (Changes Data Capture).

## Todo List
- [x] Implement RabbitMQ to send the information through a message queue
- [x] Publish the library in pip
- [ ] Complete all information in the *README.md* file
- [ ] Create a message body for mysql tracker
- [ ] Complete the unit test

⌨️ with ♥️ by **Luis Manuel Torres Trevino**